/*
** Module   : XEntity
** Abstract : DOM and SAX common interface.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130204 Created initial version.
** 002 EVL 20130214 Adding the base interface XCommon to place the XML related common features.  
** 003 CA  20130221 Added UNIQUE-ID and NAMESPACE-URI support. 
** 004 EVL 20130222 Adding SUBTYPE attribute and INSERT-BEFORE method support.
*/

package com.goldencode.p2j.xml;

import com.goldencode.p2j.util.*;

/**
 * Interface decribing the common features for DOM and SAX XML support objects.
 */
public interface XEntity
extends XCommon,
        UniqueID,
        NamespaceURI,
        SubTypeAttribute
{
   /**
    * Gets the handle associated with the DOM or SAX support object.
    * 
    * @return   The handle associated with object.
    */
   public handle getHandle();

   /**
    * Gets the the number of children objects for the current one.
    * 
    * @return   The integer number of the children.
    */
   public integer getNumChildren();

   /**
    * Sets the the subtype of the object.
    * 
    * @param    value
    *           The new value of the subtype object attribute.
    */
   public void setSubType(character value);
   
   /**
    * Sets the the subtype of the object.
    * 
    * @param    value
    *           The new value of the subtype object attribute.
    */
   public void setSubType(String value);
   
   /**
    * Inserts a node as a chaild of this document before another node.
    * 
    * @param    handle1
    *           The handle representing the child to insert.
    * @param    handle2
    *           The handle representing the XML node to be inserted before.
    * 
    * @return   The <code>true</code> in case of success <code>false</code> otherwise.
    */
   public logical insertBefore(handle handle1, handle handle2);

   /**
    * Appending the new child to the current object.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be appended.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical appendChild(handle hChild);

   /**
    * Appending the new child to the current object.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be appended.
    * @param    name
    *           The name of the child to be appended.
    * @param    type
    *           The type of the child to be appended.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical appendChild(handle hChild, character name, character type);

   /**
    * Getting the handle object of the child node with specified index.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to put
    *           the results.
    * @param    index
    *           1-based index of the child node to be retrieved.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical getChild(handle hChild, integer index);
   
   /**
    * Getting the handle object of the child node with specified index.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to put
    *           the results.
    * @param    index
    *           1-based index of the child node to be retrieved.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical getChild(handle hChild, int index);
   
   /**
    * Removing the specified child from the node.
    * 
    * @param    hChild
    *           The valid handle class instance of the child to be removed.
    * 
    * @return   The <code>true</code> in case of success
    *           <code>false</code> otherwise.
    */
   public logical removeChild(handle hChild);
}
